OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Złe hasło",
    "No user supplied" : "Niedostarczony użytkownik",
    "Authentication error" : "Błąd uwierzytelniania",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Podaj hasło odzyskiwania administratora, w przeciwnym razie wszystkie dane użytkownika zostaną utracone",
    "Wrong admin recovery password. Please check the password and try again." : "Błędne hasło odzyskiwania. Sprawdź hasło i spróbuj ponownie.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Zaplecze nie obsługuje zmiany hasła, ale klucz szyfrowania użytkownika został pomyślnie zaktualizowany.",
    "Unable to change password" : "Nie można zmienić hasła",
    "Enabled" : "Włączone",
    "Not enabled" : "Nie włączone",
    "Group already exists." : "Grupa już istnieje.",
    "Unable to add group." : "Nie można dodać grupy.",
    "Unable to delete group." : "Nie można usunąć grupy.",
    "log-level out of allowed range" : "wartość log-level spoza dozwolonego zakresu",
    "Saved" : "Zapisano",
    "test email settings" : "przetestuj ustawienia email",
    "Email sent" : "E-mail wysłany",
    "You need to set your user email before being able to send test emails." : "Musisz najpierw ustawić użytkownika e-mail, aby móc wysyłać wiadomości testowe.",
    "Invalid mail address" : "Nieprawidłowy adres email",
    "Unable to create user." : "Nie można utworzyć użytkownika.",
    "Your %s account was created" : "Twoje konto %s zostało stworzone",
    "Unable to delete user." : "Nie można usunąć użytkownika.",
    "Forbidden" : "Zabronione",
    "Invalid user" : "Nieprawidłowy użytkownik",
    "Unable to change mail address" : "Nie można zmienić adresu email",
    "Email saved" : "E-mail zapisany",
    "Your full name has been changed." : "Twoja pełna nazwa została zmieniona.",
    "Unable to change full name" : "Nie można zmienić pełnej nazwy",
    "Redis" : "Redis",
    "Security & setup warnings" : "Ostrzeżenia bezpieczeństwa i konfiguracji",
    "Sharing" : "Udostępnianie",
    "Server-side encryption" : "Szyfrowanie po stronie serwera",
    "External Storage" : "Zewnętrzna zasoby dyskowe",
    "Cron" : "Cron",
    "Email server" : "Serwer pocztowy",
    "Log" : "Logi",
    "Updates" : "Aktualizacje",
    "Couldn't remove app." : "Nie można usunąć aplikacji.",
    "Language changed" : "Zmieniono język",
    "Invalid request" : "Nieprawidłowe żądanie",
    "Admins can't remove themself from the admin group" : "Administratorzy nie mogą usunąć siebie samych z grupy administratorów",
    "Unable to add user to group %s" : "Nie można dodać użytkownika do grupy %s",
    "Unable to remove user from group %s" : "Nie można usunąć użytkownika z grupy %s",
    "Couldn't update app." : "Nie można uaktualnić aplikacji.",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Czy jesteś pewien/pewna że chcesz dodać \"{domain}\" jako zaufaną domenę?",
    "Add trusted domain" : "Dodaj zaufaną domenę",
    "Migration in progress. Please wait until the migration is finished" : "Trwa migracja. Proszę poczekać, aż migracja dobiegnie końca.",
    "Migration started …" : "Migracja rozpoczęta...",
    "Sending..." : "Wysyłam...",
    "Experimental" : "Eksperymentalny",
    "All" : "Wszystkie",
    "No apps found for your version" : "Nie znaleziono aplikacji dla twojej wersji",
    "Update to %s" : "Uaktualnij do %s",
    "Please wait...." : "Proszę czekać...",
    "Error while disabling app" : "Błąd podczas wyłączania aplikacji",
    "Disable" : "Wyłącz",
    "Enable" : "Włącz",
    "Error while enabling app" : "Błąd podczas włączania aplikacji",
    "Updating...." : "Aktualizacja w toku...",
    "Error while updating app" : "Błąd podczas aktualizacji aplikacji",
    "Updated" : "Zaktualizowano",
    "Uninstalling ...." : "Odinstalowywanie....",
    "Error while uninstalling app" : "Błąd przy odinstalowywaniu aplikacji",
    "Uninstall" : "Odinstaluj",
    "Error while loading browser sessions and device tokens" : "Błąd podczas ładowania sesji przeglądarek i tokenów urządzeń",
    "Error while creating device token" : "Błąd podczas tworzenia tokena urządzenia.",
    "Error while deleting the token" : "Błąd podczas usuwania tokena.",
    "Valid until {date}" : "Ważny do {date}",
    "Delete" : "Usuń",
    "An error occurred: {message}" : "Wystąpił błąd: {message}",
    "Select a profile picture" : "Wybierz zdjęcie profilu",
    "Very weak password" : "Bardzo słabe hasło",
    "Weak password" : "Słabe hasło",
    "So-so password" : "Mało skomplikowane hasło",
    "Good password" : "Dobre hasło",
    "Strong password" : "Mocne hasło",
    "Groups" : "Grupy",
    "Unable to delete {objName}" : "Nie można usunąć {objName}",
    "Error creating group: {message}" : "Błąd podczas tworzenia grupy: {message}",
    "A valid group name must be provided" : "Należy podać prawidłową nazwę grupy",
    "deleted {groupName}" : "usunięto {groupName}",
    "undo" : "cofnij",
    "no group" : "brak grupy",
    "never" : "nigdy",
    "deleted {userName}" : "usunięto {userName}",
    "add group" : "dodaj grupę",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Zmiana hasła spowoduje utratę danych, ponieważ odzyskiwanie danych nie jest włączone dla tego użytkownika",
    "A valid username must be provided" : "Należy podać prawidłową nazwę użytkownika",
    "Error creating user: {message}" : "Błąd podczas tworzenia użytkownika: {message}",
    "A valid password must be provided" : "Należy podać prawidłowe hasło",
    "A valid email must be provided" : "Podaj poprawny adres email",
    "__language_name__" : "polski",
    "Unlimited" : "Bez limitu",
    "Personal info" : "Informacje osobiste",
    "Sessions" : "Sesje",
    "Sync clients" : "Klienty synchronizacji",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Wszystko  (Informacje, ostrzeżenia, błędy i poważne problemy, debug)",
    "Info, warnings, errors and fatal issues" : "Informacje, ostrzeżenia, błędy i poważne problemy",
    "Warnings, errors and fatal issues" : "Ostrzeżenia, błędy i poważne problemy",
    "Errors and fatal issues" : "Błędy i poważne problemy",
    "Fatal issues only" : "Tylko poważne problemy",
    "None" : "Nic",
    "Login" : "Login",
    "Plain" : "Czysty tekst",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Wygląda na to, że ustawienia PHP ucinają bloki wklejonych dokumentów. To sprawi, że niektóre wbudowane aplikacje będą niedostępne.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dzieje się tak prawdopodobnie przez cache lub akcelerator taki jak Zend OPcache lub eAccelerator.",
    "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Twój serwer działa na platformie Windows. Zalecamy Linuxa dla optymalnych doświadczeń użytkownika.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Brak modułu PHP „fileinfo”. Zalecamy włączenie tego modułu, aby uzyskać najlepsze wyniki podczas wykrywania typów MIME.",
    "System locale can not be set to a one which supports UTF-8." : "Ustawienia regionalne systemu nie można ustawić na jeden, który obsługuje UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Oznacza to, że mogą być problemy z niektórymi znakami w nazwach plików.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Zalecamy instalację na Twoim systemie komponentów wymaganych do obsługi języków: %s",
    "Open documentation" : "Otwórz dokumentację",
    "Allow apps to use the Share API" : "Zezwalaj aplikacjom na korzystanie z API udostępniania",
    "Allow users to share via link" : "Pozwól użytkownikom współdzielić przez link",
    "Allow public uploads" : "Pozwól na  publiczne wczytywanie",
    "Enforce password protection" : "Wymuś zabezpieczenie hasłem",
    "Set default expiration date" : "Ustaw domyślną datę wygaśnięcia",
    "Allow users to send mail notification for shared files" : "Zezwól użytkownikom na wysyłanie powiadomień email dla udostępnionych plików",
    "Expire after " : "Wygaś po",
    "days" : "dniach",
    "Enforce expiration date" : "Wymuś datę wygaśnięcia",
    "Allow resharing" : "Zezwalaj na ponowne udostępnianie",
    "Restrict users to only share with users in their groups" : "Ogranicz użytkowników do współdzielenia wyłącznie pomiędzy użytkownikami swoich grup",
    "Exclude groups from sharing" : "Wyklucz grupy z udostępniania",
    "These groups will still be able to receive shares, but not to initiate them." : "Grupy te nadal będą mogli otrzymywać udostępnione udziały, ale nie do ich inicjowania.",
    "Cron was not executed yet!" : "Cron nie został jeszcze uruchomiony!",
    "Execute one task with each page loaded" : "Wykonuj jedno zadanie wraz z każdą wczytaną stroną",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php jest zarejestrowany w serwisie webcron do uruchamiania cron.php raz na 15 minut przez http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Użyj systemowej usługi cron do wywoływania cron.php co 15 minut.",
    "Enable server-side encryption" : "Włącz szyfrowanie po stronie serwera",
    "Be aware that encryption always increases the file size." : "Należy pamiętać, że szyfrowanie zawsze zwiększa rozmiar pliku.",
    "This is the final warning: Do you really want to enable encryption?" : "To ostatnie ostrzeżenie: Czy na pewno chcesz włączyć szyfrowanie?",
    "Enable encryption" : "Włącz szyfrowanie",
    "Select default encryption module:" : "Wybierz domyślny moduł szyfrujący:",
    "This is used for sending out notifications." : "To jest używane do wysyłania powiadomień",
    "Send mode" : "Tryb wysyłki",
    "Encryption" : "Szyfrowanie",
    "From address" : "Z adresu",
    "mail" : "mail",
    "Authentication method" : "Metoda autentykacji",
    "Authentication required" : "Wymagana autoryzacja",
    "Server address" : "Adres Serwera",
    "Port" : "Port",
    "Credentials" : "Poświadczenia",
    "SMTP Username" : "Użytkownik SMTP",
    "SMTP Password" : "Hasło SMTP",
    "Store credentials" : "Zapisz poświadczenia",
    "Test email settings" : "Ustawienia testowej wiadomości",
    "Send email" : "Wyślij email",
    "Download logfile" : "Pobierz plik log",
    "More" : "Więcej",
    "Less" : "Mniej",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Plik log jest większy niż 100MB. Ściąganie może trochę potrwać!",
    "Version" : "Wersja",
    "Developer documentation" : "Dokumentacja dewelopera",
    "Documentation:" : "Dokumentacja:",
    "User documentation" : "Dokumentacja użytkownika",
    "Report a bug" : "Zgłoś błąd",
    "Show description …" : "Pokaż opis ...",
    "Hide description …" : "Ukryj opis ...",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ta aplikacja nie może być zainstalowana, ponieważ nie są spełnione następujące zależności:",
    "Enable only for specific groups" : "Włącz tylko dla określonych grup",
    "Uninstall App" : "Odinstaluj aplikację",
    "Enable experimental apps" : "Włącz eksperymentalne aplikacje",
    "Common Name" : "Nazwa CN",
    "Valid until" : "Ważny do",
    "Issued By" : "Wydany przez",
    "Valid until %s" : "Ważny do %s",
    "Import root certificate" : "Importuj główny certyfikat",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Witaj,<br><br>informujemy, że teraz masz konto na %s .<br><br>Twoja nazwa użytkownika: %s<br>Dostęp pod adresem: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Pozdrawiam!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Witaj,\n\ninformujemy, że teraz masz konto na %s .\n\nTwoja nazwa użytkownika:: %s\nDostęp pod adresem: %s\n\n",
    "Administrator documentation" : "Dokumentacja Administratora",
    "Online documentation" : "Dokumentacja Online",
    "Forum" : "Forum",
    "Commercial support" : "Wsparcie komercyjne",
    "Profile picture" : "Zdjęcie profilu",
    "Upload new" : "Wczytaj nowe",
    "Remove image" : "Usuń zdjęcie",
    "Cancel" : "Anuluj",
    "Full name" : "Pełna nazwa",
    "No display name set" : "Brak nazwa wyświetlanej",
    "Email" : "Email",
    "Your email address" : "Twój adres e-mail",
    "No email address set" : "Brak adresu email",
    "Password" : "Hasło",
    "Unable to change your password" : "Nie można zmienić hasła",
    "Current password" : "Bieżące hasło",
    "New password" : "Nowe hasło",
    "Change password" : "Zmień hasło",
    "Language" : "Język",
    "Help translate" : "Pomóż w tłumaczeniu",
    "Name" : "Nazwa",
    "Username" : "Nazwa użytkownika",
    "Done" : "Ukończono",
    "Get the apps to sync your files" : "Pobierz aplikacje żeby synchronizować swoje pliki",
    "Desktop client" : "Klient na komputer",
    "Android app" : "Aplikacja Android",
    "iOS app" : "Aplikacja iOS",
    "Show First Run Wizard again" : "Uruchom ponownie kreatora pierwszego uruchomienia",
    "Show storage location" : "Pokaż miejsce przechowywania",
    "Show last log in" : "Pokaż ostatni login",
    "Show user backend" : "Pokaż moduł użytkownika",
    "Send email to new user" : "Wyślij email do nowego użytkownika",
    "Show email address" : "Pokaż adres email",
    "E-Mail" : "E-mail",
    "Create" : "Utwórz",
    "Admin Recovery Password" : "Odzyskiwanie hasła administratora",
    "Enter the recovery password in order to recover the users files during password change" : "Wpisz hasło odzyskiwania, aby odzyskać pliki użytkowników podczas zmiany hasła",
    "Add Group" : "Dodaj grupę",
    "Group" : "Grupa",
    "Everyone" : "Wszyscy",
    "Admins" : "Administratorzy",
    "Default Quota" : "Domyślny udział",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Proszę ustawić ograniczenie zasobów (np. \"512 MB\" albo \"12 GB)",
    "Other" : "Inne",
    "Full Name" : "Pełna nazwa",
    "Group Admin for" : "Grupa Admin dla",
    "Quota" : "Udział",
    "Storage Location" : "Lokalizacja magazynu",
    "Last Login" : "Ostatnio zalogowany",
    "change full name" : "Zmień pełna nazwę",
    "set new password" : "ustaw nowe hasło",
    "change email address" : "zmień adres email",
    "Default" : "Domyślny"
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
